Module: wine
Branch: master
Commit: d66ded939c4c21fbc3bd21e9e48a30a41303e9fc
URL: http://source.winehq.org/git/wine.git/?a=commit;h=d66ded939c4c21fbc3bd21e9e…
Author: Roderick Colenbrander <thunderbird2k(a)gmail.com>
Date: Tue May 19 21:42:09 2009 +0200
wgl: Set PFD_GENERIC_FORMAT on bitmap formats instead of PFD_GENERIC_ACCELERATED.
---
dlls/winex11.drv/opengl.c | 8 ++++----
1 files changed, 4 insertions(+), 4 deletions(-)
diff --git a/programs/winedbg/rsrc.rc b/programs/winedbg/rsrc.rc
index 31ce2d2..fbc07d7 100644
--- a/programs/winedbg/rsrc.rc
+++ b/programs/winedbg/rsrc.rc
@@ -25,3 +25,4 @@
#include "rsrc_En.rc"
#include "rsrc_Ko.rc"
+#include "rsrc_Nl.rc"
diff --git a/programs/winedbg/rsrc_Nl.rc b/programs/winedbg/rsrc_Nl.rc
new file mode 100644
index 0000000..01be67b
--- /dev/null
+++ b/programs/winedbg/rsrc_Nl.rc
@@ -0,0 +1,53 @@
+/*
+ * Dutch Language Support
+ *
+ * Copyright 2009 Frans Kool
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
+ */
+
+LANGUAGE LANG_DUTCH, SUBLANG_NEUTRAL
+
+IDM_DEBUG_POPUP MENU
+BEGIN
+ POPUP ""
+ BEGIN
+ MENUITEM "&Debug", ID_DEBUG
+ END
+END
+
+IDD_CRASH_DLG DIALOGEX 100, 100, 273, 175
+STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | WS_POPUP | WS_CAPTION | WS_SYSMENU
+CAPTION "Programma Fout"
+FONT 8, "Tahoma"
+BEGIN
+ LTEXT "",IDC_STATIC_BG,0,0,273,52,WS_BORDER,0
+ LTEXT "Het programma %s is een serieus probleem tegengekomen en moet \
+ afgesloten worden. Excuses voor het ongemak.",
+ IDC_STATIC_TXT1,27,10,224,30
+ LTEXT "Dit kan veroorzaakt worden door een probleem in het programma of een fout in Wine. \
+ U kunt zoeken op http://appdb.winehq.org naar tips over het draaien \
+ van dit programma.\n\n\
+ Als dit probleem niet optreedt onder Windows en nog niet is gerapporteerd, \
+ dan kunt u het rapporteren op http://bugs.winehq.org.",IDC_STATIC_TXT2,27,60,224,100
+ DEFPUSHBUTTON "Sluiten", IDOK, 205, 151, 60, 16, WS_TABSTOP
+END
+
+STRINGTABLE
+BEGIN
+ IDS_AUTO_CAPTION "Wine programma crash"
+ IDS_INVALID_PARAMS "Interne fouten - foutieve parameters ontvangen"
+ IDS_UNIDENTIFIED "(onbekend)"
+END
diff --git a/dlls/winex11.drv/opengl.c b/dlls/winex11.drv/opengl.c
index 3d7c456..b15b4e2 100644
--- a/dlls/winex11.drv/opengl.c
+++ b/dlls/winex11.drv/opengl.c
@@ -939,7 +939,7 @@ static WineGLPixelFormat *get_formats(Display *display, int *size_ret, int *onsc
list[size].fmt_id = fmt_id;
list[size].render_type = get_render_type_from_fbconfig(display, cfgs[i]);
list[size].offscreenOnly = FALSE;
- list[size].dwFlags = PFD_DRAW_TO_BITMAP | PFD_SUPPORT_GDI | PFD_GENERIC_ACCELERATED;
+ list[size].dwFlags = PFD_DRAW_TO_BITMAP | PFD_SUPPORT_GDI | PFD_GENERIC_FORMAT;
size++;
onscreen_size++;
}
@@ -1411,11 +1411,11 @@ int CDECL X11DRV_DescribePixelFormat(X11DRV_PDEVICE *physDev,
ppfd->dwFlags |= fmt->dwFlags & (PFD_DRAW_TO_BITMAP | PFD_SUPPORT_GDI);
/* PFD_GENERIC_FORMAT - gdi software rendering
- * PFD_GENERIC_ACCELERATED - some parts are accelerated by a display driver (ICD or MCD)
+ * PFD_GENERIC_ACCELERATED - some parts are accelerated by a display driver (MCD e.g. 3dfx minigl)
* none set - full hardware accelerated by a ICD
*
- * We only set PFD_GENERIC_ACCELERATED on bitmap formats (see get_formats) as that's what ATI and Nvidia Windows drivers do */
- ppfd->dwFlags |= fmt->dwFlags & PFD_GENERIC_ACCELERATED;
+ * We only set PFD_GENERIC_FORMAT on bitmap formats (see get_formats) as that's what ATI and Nvidia Windows drivers do */
+ ppfd->dwFlags |= fmt->dwFlags & (PFD_GENERIC_FORMAT | PFD_GENERIC_ACCELERATED);
pglXGetFBConfigAttrib(gdi_display, fmt->fbconfig, GLX_DOUBLEBUFFER, &value);
if (value) {
Module: wine
Branch: master
Commit: d4e1d88722208bf8f4a1d3b4d8956c88add8a0a1
URL: http://source.winehq.org/git/wine.git/?a=commit;h=d4e1d88722208bf8f4a1d3b4d…
Author: Frans Kool <Frans.Kool(a)gmail.com>
Date: Tue May 19 16:03:22 2009 +0200
winedbg: Add Dutch translations.
---
programs/winedbg/rsrc.rc | 1 +
programs/winedbg/rsrc_Nl.rc | 53 +++++++++++++++++++++++++++++++++++++++++++
2 files changed, 54 insertions(+), 0 deletions(-)